@@ -1,6 +1,6 @@
 package Quantum::Superpositions::Lazy::Role::Collapsible;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use v5.24; use warnings;
 use Moo::Role;
@@ -52,8 +52,6 @@ sub _operate(@args)
 	return $self->operate($type, @args);
 }
 
-
-
 use namespace::clean;
 
 requires qw(
@@ -118,6 +116,11 @@ sub operate($self, $type, @args)
 	}
 }
 
+sub transform($self, $coderef)
+{
+	return $self->operate("_transform", $coderef, undef);
+}
+
 sub to_ket_notation($self)
 {
 	return join " + ", map {
